@@ -1,13 +1,17 @@
 /*
  * This file defines the SIP library internal interfaces.
  *
- * Copyright (c) 2009 Riverbank Computing Limited <info@riverbankcomputing.com>
- * 
+ * Copyright (c) 2011 Riverbank Computing Limited <info@riverbankcomputing.com>
+ *
  * This file is part of SIP.
- * 
+ *
  * This copy of SIP is licensed for use under the terms of the SIP License
  * Agreement.  See the file LICENSE for more details.
- * 
+ *
+ * This copy of SIP may also used under the terms of the GNU General Public
+ * License v2 or v3 as published by the Free Software Foundation which can be
+ * found in the files LICENSE-GPL2 and LICENSE-GPL3 included in this package.
+ *
  * SIP is supplied WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
@@ -59,7 +63,30 @@ extern PyTypeObject sipMethodDescr_Type;
 PyObject *sipMethodDescr_New(PyMethodDef *pmd);
 
 extern PyTypeObject sipVariableDescr_Type;
-PyObject *sipVariableDescr_New(sipVariableDef *vd, const sipClassTypeDef *ctd);
+PyObject *sipVariableDescr_New(sipVariableDef *vd, const sipTypeDef *td,
+    const sipContainerDef *cod);
+
+
+/*
+ * Support for API versions.
+ */
+PyObject *sipGetAPI(PyObject *self, PyObject *args);
+PyObject *sipSetAPI(PyObject *self, PyObject *args);
+int sip_api_is_api_enabled(const char *name, int from, int to);
+int sipIsRangeEnabled(sipExportedModuleDef *em, int range_index);
+int sipInitAPI(sipExportedModuleDef *em, PyObject *mod_dict);
+
+
+/*
+ * Support for void pointers.
+ */
+extern PyTypeObject sipVoidPtr_Type;
+void *sip_api_convert_to_void_ptr(PyObject *obj);
+PyObject *sip_api_convert_from_void_ptr(void *val);
+PyObject *sip_api_convert_from_const_void_ptr(const void *val);
+PyObject *sip_api_convert_from_void_ptr_and_size(void *val, SIP_SSIZE_T size);
+PyObject *sip_api_convert_from_const_void_ptr_and_size(const void *val,
+        SIP_SSIZE_T size);
 
 
 extern sipQtAPI *sipQtSupport;  /* The Qt support API. */
@@ -79,6 +106,7 @@ PyObject *sip_api_disconnect_rx(PyObject *txObj, const char *sig,
  */
 void *sip_api_malloc(size_t nbytes);
 void sip_api_free(void *mem);
+void *sip_api_get_address(sipSimpleWrapper *w);
 void *sip_api_get_cpp_ptr(sipSimpleWrapper *w, const sipTypeDef *td);
 PyObject *sip_api_convert_from_type(void *cppPtr, const sipTypeDef *td,
         PyObject *transferObj);
@@ -112,8 +140,6 @@ int sipOMRemoveObject(sipObjectMap *om, sipSimpleWrapper *val);
 
 void sipSetBool(void *ptr,int val);
 
-void *sipGetAddress(sipSimpleWrapper *w);
-
 
 #ifdef __cplusplus
 }
